Re: [maemo-developers] problem with dspmp3sink (was: problem with gstreamer and dsppcm)

2006-08-21 Thread Eero Tamminen
Hi,

 Also I noticed that gstreamer is not very reliable, at least when using
 it from mplayer. It can freeze or reboot the device sometimes. That's not
 something that should be expected from high level API. If I detect some
 reliable pattern in reproducing these bugs, I'll report it to bugzilla
 for sure. But right now just using mplayer and lots of seeking in video
 can cause these bugs reasonably fast.

First I would recommend using just top to see whether mplayer
is either:
- Leaking memory
- Otherwise using too much memory
Either by itself or forcing gstreamer to do that.

If that is the case, the bug is in the mplayer (or gstreamer (plugin))
and it needs to be fixed.  For debugging the leaks, I would recommend
using Valgrind on x86.


- Eero

PS. The applications in the device have been done so that they integrate
into the the device memory management framework; if they have dynamic
or large memory usage, before doing large allocs, they check whether
system has enough memory for those, they react to system low memory
notifications etc.

If an application forces the kernel to the OOM (out of memory)
situation, it will by default kill the application requesting
memory.  However, if mplayer is run as root, its killing is
avoided (note most of the framework processes are run as normal
user).  Also, if you're using Desktop while mplayer triggers
device OOM, it's Desktop using memory and kernel might kill it
(which reboots the device).

FYI: Only way to handle OOM correctly is to avoid triggering it,
trying something fancy (in kernel) in that situation is AFAIK
wraught with deadlocks.

___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers


Re: [maemo-users] Re: [maemo-developers] Future features for Maemo Desktop (Task Navigator, Home, Status bar)?

2006-08-21 Thread Eero Tamminen
Hi,

   And lastly, the Task Navigator bar width should be configurable.
There is no reason for its fattness as it is - it is just a waste
of desktop realstate, IMHO.

 Actually, there is a reason -- so that you could hit the icons with your
 thumb.  It would be difficult if the bar was slimmer, or the icons
 smaller.

I think making Task Navigator thinner would also require new theme.
Besides the TN graphics, the Desktop and titlebar gfx elements would
seem to depend from the current size.  The installed plugins also
expect at least a certain width into which their icons fit.

So, maybe the new feature would be to make TN width into themable
property... Then somebody could make a thumbless theme. ;-)


- Eero

___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers


[maemo-developers] automatic byte order check

2006-08-21 Thread Detlef Schmicker
Hello,

I had a look at the vncviewer and saw, that it is working in the sandbox
in connection with vino (gnome vnc server). On the device the CoRRE
encoding does not work.

Probably it is a byte order problem. The code has a lot of byte order
(e.g. GUINT16_TO_BE). Is there a way to automaticaly warn critical
points at compilation? Are there any tools?

Thanks a lot
Detlef

-- 
Detlef Schmicker [EMAIL PROTECTED]

___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers


Re: [maemo-developers] automatic byte order check

2006-08-21 Thread Jean-Baptiste Note

Hello,

The (linux) kernel has endianess-aware integer types (__be_u16 or
something similar) which allow the access to be checked for endianess
problems (basically reading an endianess-annotated type into a
non-endianess-specified (ie native endianess) type must go through a
byte order macro).

You have to annotate by hand all shared structures with these types.
In your case, this would be all network-shared structures.

I'm not sure the compiler does the check though, it may be an external
tool. It could be however very interesting to generalize this outside
of the kernel.

JB

--
Jean-Baptiste Note
___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers


RE: [maemo-developers] Future features for Maemo Desktop (TaskNavigator, Home, Status bar)?

2006-08-21 Thread Karoliina.T.Salminen
Hello,

Thanks for so far your replies, I have got a large number of feature
proposals already.

I am still accepting feature ideas to my roadmap, so please keep on
posting them on the list. What would you wish from your dream-device in
terms of UI framework (Task Navigator, Home, Status bar, Control panel)?
Is there something you would like to have done better or something that
you'd like to have to be done in a completely different way? Don't limit
your imagination to how e.g. Task Navigator works now, but think how it
would ideally work, without the limits? What would be ultra-cool there?
Please think it also out of context of the current hardware, you can
suggest also ideas that would be nice on the platform despite they
aren't really realistic with the current 770 hardware. Any cool ideas
are warmly welcome.

Thanks!

Best Wishes,
Karoliina Salminen
http://www.karoliinasalminen.com/blog


___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers


Re: [maemo-developers] Future features for Maemo Desktop (TaskNavigator, Home, Status bar)?

2006-08-21 Thread Kees Jongenburger

On 8/21/06, [EMAIL PROTECTED]
[EMAIL PROTECTED] wrote:

Hello,

Thanks for so far your replies, I have got a large number of feature
proposals already.

I am still accepting feature ideas to my roadmap, so please keep on
posting them on the list. What would you wish from your dream-device in
terms of UI framework (Task Navigator, Home, Status bar, Control panel)?
Is there something you would like to have done better or something that
you'd like to have to be done in a completely different way? Don't limit
your imagination to how e.g. Task Navigator works now, but think how it
would ideally work, without the limits? What would be ultra-cool there?


I think some kind of UI that acts like the mezzo interface with active corners
http://www.symphonyos.com/download/
(debian package who dares porting it?)

http://www.jdistro.com/mezzo/
(screen shots of the jdistro impl)




Please think it also out of context of the current hardware, you can
suggest also ideas that would be nice on the platform despite they
aren't really realistic with the current 770 hardware. Any cool ideas
are warmly welcome.

svg/pdf based display rendering, animations, alpha transparency

text input based on most common words, I have seen this about 10 years ago
the letters flow from right to left and the most common words/letters
appear in front of you, using the stylus it is still possible to move
up or down to follow a different input path and if the words appears
just as you liked you can move the stylus to the right to make the
letter appear faster. I will try to find a demo online.

greetings
___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers


Re: [maemo-developers] Future features for Maemo Desktop (TaskNavigator, Home, Status bar)?

2006-08-21 Thread Kalle Vahlman

2006/8/21, Kees Jongenburger [EMAIL PROTECTED]:

On 8/21/06, [EMAIL PROTECTED]
[EMAIL PROTECTED] wrote:
 Please think it also out of context of the current hardware, you can
 suggest also ideas that would be nice on the platform despite they
 aren't really realistic with the current 770 hardware. Any cool ideas
 are warmly welcome.
svg/pdf based display rendering, animations, alpha transparency


I guess they would also like to know where those should be applied ;)


text input based on most common words, I have seen this about 10 years ago
the letters flow from right to left and the most common words/letters
appear in front of you, using the stylus it is still possible to move
up or down to follow a different input path and if the words appears
just as you liked you can move the stylus to the right to make the
letter appear faster. I will try to find a demo online.


Sounds exactly like dasher:
http://www.maemo.org/maemowiki/ApplicationCatalogWip#head-ff3915a32305bd527275defd8e2f618bc8e30bc7


--
Kalle Vahlman, [EMAIL PROTECTED]
Powered by http://movial.fi
Interesting stuff at http://syslog.movial.fi
___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers


Re: [maemo-developers] Modified initfs with onscreen boot menu

2006-08-21 Thread Marius Vollmer
ext Frantisek Dufka [EMAIL PROTECTED] writes:

 I managed to make initfs with boot menu (as mentioned here
 http://maemo.org/pipermail/maemo-developers/2006-July/004653.html )
 sort of working.

Excellent!  I am using it right now, and will write up some
instructions for how to put Sardine on the MMC.

Hopefully, we can just distribute a modified initfs so that people can
just flash it.  Or even make it an official feature of our default
initfs.  Would you be willing to license your code with the GPL?

Also, I already have a small UI improvement suggestion: what about
always showing the boot menu, not only when you hit the MENU key?  I
tend to miss the window where the key needs to be pressed all the
time.  Maybe the menu could be shown when the root device is ask?
___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers


Re: [maemo-developers] Future features for Maemo Desktop (TaskNavigator, Home, Status bar)?

2006-08-21 Thread Kees Jongenburger

On 8/21/06, Kalle Vahlman [EMAIL PROTECTED] wrote:

 text input based on most common words, I have seen this about 10 years ago
 the letters flow from right to left and the most common words/letters
 appear in front of you, using the stylus it is still possible to move
 up or down to follow a different input path and if the words appears
 just as you liked you can move the stylus to the right to make the
 letter appear faster. I will try to find a demo online.

Sounds exactly like dasher:

Yes ! that's it. thank you very much


http://www.maemo.org/maemowiki/ApplicationCatalogWip#head-ff3915a32305bd527275defd8e2f618bc8e30bc7


I also just tried the online demo
http://www.inference.phy.cam.ac.uk/dasher/TryJavaDasherNow.html
But In my memory it worked even better !

greetings
___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers


Re: [maemo-developers] Modified initfs with onscreen boot menu

2006-08-21 Thread Marius Vollmer
Marius Vollmer [EMAIL PROTECTED] writes:

 Also, I already have a small UI improvement suggestion: what about
 always showing the boot menu, not only when you hit the MENU key?  I
 tend to miss the window where the key needs to be pressed all the
 time.  Maybe the menu could be shown when the root device is ask?

Here is a small patch to implement this.

--- bootmenu.sh 2006-08-13 10:50:06.0 +0300
+++ bootmenu-ask.sh 2006-08-21 18:17:30.0 +0300
@@ -110,8 +110,8 @@
 i=$((i+1))
 done
 
-#show onscreeen menu if menu key was pressed
-if [ $HWKEYSTATE = $KEY_MENU ] ; then
+#show onscreeen menu if menu key was pressed or when the root device is ask
+if [ $HWKEYSTATE = $KEY_MENU -o $default_root = ask ] ; then
menu_init
menu_redraw
menu_loop
___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers


Re: [maemo-developers] problem with dspmp3sink (was: problem with gstreamer and dsppcm)

2006-08-21 Thread Charles 'Buck' Krasic
Siarhei,

Just in case you have not done it already, enabling swap in your device
can help a lot to prevent out-of-memory errors.Maybe this will help
with mplayer/gstreamer stability.

I personally suspect  a design flaw in the current Linux VM subsystem.  
I've observed that if an application allocates memory rapidly,  the
kernel may fail to reclaim pages quickly enough from the page and buffer
caches (they are only caches after all), so it actually denies the
allocation request. For example, with zero swap, on a machine with
1G of ram, and 500M of it pseudo-free (used by caches), I've seen
moderate allocations fail--like when starting an application like
firefox.Enabling even a small amount of swap seems to dramatically
change this behaviour.

-- Buck


Eero Tamminen wrote:

Hi,

  

Also I noticed that gstreamer is not very reliable, at least when using
it from mplayer. It can freeze or reboot the device sometimes. That's not
something that should be expected from high level API. If I detect some
reliable pattern in reproducing these bugs, I'll report it to bugzilla
for sure. But right now just using mplayer and lots of seeking in video
can cause these bugs reasonably fast.



First I would recommend using just top to see whether mplayer
is either:
- Leaking memory
- Otherwise using too much memory
Either by itself or forcing gstreamer to do that.

If that is the case, the bug is in the mplayer (or gstreamer (plugin))
and it needs to be fixed.  For debugging the leaks, I would recommend
using Valgrind on x86.


   - Eero

PS. The applications in the device have been done so that they integrate
into the the device memory management framework; if they have dynamic
or large memory usage, before doing large allocs, they check whether
system has enough memory for those, they react to system low memory
notifications etc.

If an application forces the kernel to the OOM (out of memory)
situation, it will by default kill the application requesting
memory.  However, if mplayer is run as root, its killing is
avoided (note most of the framework processes are run as normal
user).  Also, if you're using Desktop while mplayer triggers
device OOM, it's Desktop using memory and kernel might kill it
(which reboots the device).

FYI: Only way to handle OOM correctly is to avoid triggering it,
trying something fancy (in kernel) in that situation is AFAIK
wraught with deadlocks.

___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers
  


begin:vcard
fn:Charles 'Buck' Krasic
n:Krasic;Charles 'Buck'
org:University of British Columbia;Department of Computer Science
adr:;;201-2366 Main Mall;Vancouver;B.C.;V6T 1Z4;Canada
email;internet:[EMAIL PROTECTED]
title:Assistant Professor
tel;work:(604) 822-5628
tel;fax:(604) 822-5485
tel;cell:(604) 313-9429
x-mozilla-html:FALSE
url:http://www.cs.ubc.ca/~krasic/
version:2.1
end:vcard

___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers


Re: [maemo-developers] VoIP through SIP

2006-08-21 Thread Johannes Eickhold
Am Montag, den 21.08.2006, 00:58 +0200 schrieb Jaime Ruiz Frontera:
  On Sat, 2006-08-19 at 18:18 +0200, [EMAIL PROTECTED] wrote:
  Hello to all!
 
  Hi Jaime.
 
  I'm wondering if is there any voip application supporting SIP in which
  you
  can choose the server you want.
 
  If you don't fear the power of the command line please feel free to
  check out sofsip-cli. It is a command line SIP client based on Nokia's
  sofia-sip SIP stack. Debian packages for the 770 and further info are
  available here: http://jonek.hexbox.de/?page_id=43
 
  Feedback is highly welcome.
 
 Hi Jonek,
 I just tried it. I used it with voipbuster (www.voipbuster.com). I could
 register with my username and password but when I try to make a call it
 finishes with a segmentation fault. If you need details just tell me.

Nice to see somebody taking the challange of sofsip-cli :). It is not
very userfriendly or pretty looking but serves testing purposes very
well as it does as an introduction to the sofia-sip library.

If you need support please refer to the sofia-sip mailing list at [1].

For further help on the 770 I definately need more info from you! At
least enough to replicate your error or some debugging output as was
suggested on the mailing list. You can find an unstriped version of the
sofsip_cli binary here [2].

Greets,
  Jonek.

[1] https://lists.sourceforge.net/lists/listinfo/sofia-sip-devel
[2] http://jonek.hexbox.de/uploads/2006/07/sofsip_cli
___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers


[maemo-developers] Re: [maemo-users] Future features for Maemo Desktop (Task Navigator, Home, Status bar)?

2006-08-21 Thread Peter Robinson

EVDO and HSDPA wireless support should also added as an optional feature.
This may require of course a new hardware release which supports one of the
cardbus formats on which the EVDO and HSDPA cards can be obtained. By way of
example, here is the url to a www page at the Linksys www site that shows
the new form factor, in this case for a gig-e card,  that goes under the
marketing name of ExpressCard Adapter


Well if would support it through bluetooth if the phone your
connecting to supports it.

Peter
___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers


Re: [maemo-developers] Modified initfs with onscreen boot menu

2006-08-21 Thread Carlos Guerreiro
 Marius Vollmer [EMAIL PROTECTED] writes:
 
  Also, I already have a small UI improvement suggestion: what about
  always showing the boot menu, not only when you hit the MENU key?  I
  tend to miss the window where the key needs to be pressed all the
  time.  Maybe the menu could be shown when the root device is ask?
 
 Here is a small patch to implement this.
 
 --- bootmenu.sh   2006-08-13 10:50:06.0 +0300
 +++ bootmenu-ask.sh   2006-08-21 18:17:30.0 +0300
 @@ -110,8 +110,8 @@
  i=$((i+1))
  done
  
 -#show onscreeen menu if menu key was pressed
 -if [ $HWKEYSTATE = $KEY_MENU ] ; then
 +#show onscreeen menu if menu key was pressed or when the root device is ask
 +if [ $HWKEYSTATE = $KEY_MENU -o $default_root = ask ] ; then
   menu_init
   menu_redraw
   menu_loop

Frantisek, Marius, that's fantastic work!
This is a key piece of work to enable people to try out and follow up
Sardine on the 770 without having to give up using it. I'm going to try
it out ASAP :-)

___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers


RE: [maemo-developers] Future features for Maemo Desktop (TaskNavigator, Home, Status bar)?

2006-08-21 Thread Ted Gould

On Mon, 21 Aug 2006, [EMAIL PROTECTED] wrote:

Please think it also out of context of the current hardware, you can
suggest also ideas that would be nice on the platform despite they
aren't really realistic with the current 770 hardware. Any cool ideas
are warmly welcome.


Well, if you're going to go that broad...

I think there are a few 'little' things that could be put into the 
hardware to make it more interesting. (okay, as I kept typing this e-mail 
got to more than that...)


- Light sensor.  I really miss having the backlight controlled by the 
available light like on my Powerbook.


- Accelerometer.  I'm not sure exactly what this would be used for, but I 
think it has interesing applications.  Perhaps use with GPS to over time 
get more exact coordinates?  Maybe take gesture based browsing to the 
next level?


- Recharge over USB.  I realize this is more a Motorola Thing rather 
than a Nokia Thing.  But, for those who travel, reducing the number of 
power supplies needed is a wonderful gift.


- Full MMC slot.  I don't know about the space, and I don't really want 
the device to be bigger, but MMC cards are much easier to find (have 
several at home already)


- Better handwriting recognition.  It's usable, but could be much better. 
It would also be really cool if it was open source.


- Voice support.  Things like read my IMs or speak a webpage would be nice 
while doing other things.  I'm not aware of any device that has this well 
integrated and that 'just works.'  But, people have talked about it for 
years and years, I still want it.


- Xara.  The Xara folks have a really, really, fast renderer without using 
hardware support.  I think it would be really cool to have a version of 
Xara that would work on the 770.  I think they're a company that is trying 
to figure out where to go with the MS graphics announcement.  I don't 
think they'd port it to the 770 without encouragement from Nokia.  I do 
think it would be a very nice tool on the 770 though.


- Bonjour.  I've heard (but never tried) that if a bunch of Macs are 
sitting around, they can find each other and IM using Bonjour.  The 
example relayed to me was at a conference the reporter wasn't close enough 
to the speaker to get a good picture.  So, he got on IM and found someone 
closer to send him a picture.  It would be very cool to do similar stuff, 
and connect to the same Macs, through the 770.


- LEAP support.  I'm not sure if Cisco allows anyone to know about LEAP, 
especially in an open platform.  But, it'd be nice to be able to log on to 
Cisco wireless.



Okay, I think that's all on my somewhat reasonable list.  If you guys 
figure out how to fit in peace in the middle east too I think you'll 
have everything covered ;)


--Ted

___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers


RE: [maemo-developers] Modified initfs with onscreen boot menu

2006-08-21 Thread Jason Mills
So, assuming you had the correct partitions set up on an RS-MMC/MMCmobile
card beforehand...
 
You -could- install the modified bootprompt initfs to the 770's flash
-once-, and then ship releases of Sardine in such a manner that all you'd
need to do is `dd` the various stages to high(er) numbered partitions on the
card. Extra points to Nokia/Maemo.org if they add this loader code into the
flasher application. ;-)
 
 
Swap cards, and you can boot to Sardine. Swap them back, and you have your
regular environment.
 
... And n'er the twain shall meet. (R. Kipling)
 
 
As an added benefit, the flash memory blocks you're burning out by reflashing
constantly are on the RS-MMC/MMCmobile card, and //NOT// on the board-mounted
flash memory. :-)
 
 
 
If my math is right, you'd need an RS-MMC/MMCmobile card of at least 256 MB.
Street cost of these is negligible compared to the cost of the 770.
 
 
 
That would give you:
 xxx12 MB (256,000,000 Bytes vs. 256 MB loss)
 
 P0  -DOS Partition Table Descriptior
 P1p*   48 MB Memory Card fs
 P2p 4 MB (Sardine initfs + scratch)
 P3p   128 MB rootfs+userfs
 P4E -DOS Extended Partition Table Descriptor
 P5e64 MB swapfs
 
   256 MB
 
Anything above that point would be partition 6 (extended), and non of the
OS's business. :-)
 
 
-JMills
 
 



From: [EMAIL PROTECTED] on behalf of Carlos Guerreiro
Sent: Mon 21-Aug-06 12:58
To: Marius Vollmer
Cc: maemo-dev List; ext Frantisek Dufka
Subject: Re: [maemo-developers] Modified initfs with onscreen boot menu



 Marius Vollmer [EMAIL PROTECTED] writes:

  Also, I already have a small UI improvement suggestion: what about
  always showing the boot menu, not only when you hit the MENU key?  I
  tend to miss the window where the key needs to be pressed all the
  time.  Maybe the menu could be shown when the root device is ask?

 Here is a small patch to implement this.

 --- bootmenu.sh   2006-08-13 10:50:06.0 +0300
 +++ bootmenu-ask.sh   2006-08-21 18:17:30.0 +0300
 @@ -110,8 +110,8 @@
  i=$((i+1))
  done
 
 -#show onscreeen menu if menu key was pressed
 -if [ $HWKEYSTATE = $KEY_MENU ] ; then
 +#show onscreeen menu if menu key was pressed or when the root device is
ask
 +if [ $HWKEYSTATE = $KEY_MENU -o $default_root = ask ] ; then
   menu_init
   menu_redraw
   menu_loop

Frantisek, Marius, that's fantastic work!
This is a key piece of work to enable people to try out and follow up
Sardine on the 770 without having to give up using it. I'm going to try
it out ASAP :-)

___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers


___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers


RE: [maemo-developers] Future features for Maemo Desktop (TaskNavigator, Home, Status bar)?

2006-08-21 Thread Andrew Barr
On Mon, 2006-08-21 at 15:57 -0500, Ted Gould wrote:
 - Bonjour.  I've heard (but never tried) that if a bunch of Macs are 
 sitting around, they can find each other and IM using Bonjour.  The 
 example relayed to me was at a conference the reporter wasn't close enough 
 to the speaker to get a good picture.  So, he got on IM and found someone 
 closer to send him a picture.  It would be very cool to do similar stuff, 
 and connect to the same Macs, through the 770.

I was going to try compiling avahi-daemon for this purpose--it makes
addressing a device in an ad-hoc network with link-local addresses MUCH
easier, among other things.

The IM bits are supported by Gaim 2.0 beta releases.

 - LEAP support.  I'm not sure if Cisco allows anyone to know about LEAP, 
 especially in an open platform.  But, it'd be nice to be able to log on to 
 Cisco wireless.

This has been long supported by wpa_supplicant (no thanks to Cisco
though). Unfortunately, the Nokia IAP software is closed-source and I
don't know if it's related to wpa_supplicant at all. You might have some
luck with wpa_supplicant but unless the proprietary WLAN driver supports
the latest WE extensions or the prism54 wpa_supplicant driver you're
likely out of luck.

-- 
Andrew Barr | http://www.oakcourt.dyndns.org/~andrew/

All parts should go together without forcing. You must remember that
the parts you are reassembling were disassembled by you. Therefore, if
you can't get them together again, there must be a reason. By all
means, do not use a hammer.
  -- IBM maintenance manual (1925)
___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers


[maemo-developers] Minimo maemo port available.

2006-08-21 Thread Antonio Gomes

Guys,

I am happy to announce that finally I got an end user friendly version
of Minimo/Mozilla browser [1] running on Maemo 2.x platform/Nokia 770.
Minimo browser is a slimmed down version mozilla (same branch  as
firefox 1.x - 1_8_Branch), targeting small devices. At this stage, tt
features (among others):

* It is possible to set up it to get laucned in fullscreen mode -
almost a kiosk mode :)
* Tabbed browsing.

I mostly keep track of my activities at my blog
[http://tonikitoo.blogspot.com/]. Instruction to install it via
repository is also there [2].

The port is not complete yet (so as the minimo development): bug and
coming features will make it better, but it surfers on the web
greatly.

NOTE: As firefox' , minimo's UI is not built using GTK-based as GUI,
but XUL instead, which is not Hildonizable currently.
NOTE2: menus are on right/left bottom buttons.
NOTE3: virtual keyboard thumb-mode and handwrite recognition supports
are not implemented yet, so it requires normal vkb for inputting.

Any feedback is appreciated.

[1] http://www.mozilla.org/projects/minimo
[2] http://tonikitoo.blogspot.com/2006/08/minimo-0164-maemo-port-available.html

--
--Antonio Gomes
___
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers